Learn R Programming

TFactSR (version 0.99.0)

calculateEnrichmentTest: performs enrichment analysis

Description

This function performs enrichment test (ET) based on Fisher's exact test

Usage

calculateEnrichmentTest(
  DEGs,
  catalog,
  TFs,
  TF.col = "TF..OFFICIAL_TF_CODING_GENE_NAME."
)

Value

data.frame

Arguments

DEGs

a character vector of DEGs (differentially expressed genes)

catalog

a data frame of TFactS catalog (ver. 2)

TFs

a character vector of transcription factor

TF.col

the name of the column that contains the TF names

Author

Atsushi Fukushima Definition: m is the number of target genes annotated for the TF under consideration n is the number of query genes N is the number of regulations in the catalog k is the number of query genes that are annotated as regulated by TF (i.e., the intersection between the query and the TF signature)

References

Essaghir A et al. Nucleic Acids Res. 2010 Jun;38(11):e120.

Examples

Run this code
data(DEGs)
data(catalog)

tftg <- extractTFTG(DEGs, catalog)
TFs <- tftg$TFs

res <- calculateEnrichmentTest(DEGs, catalog, TFs)

Run the code above in your browser using DataLab