a character vector of DEGs (differentially expressed genes)
catalog
a data frame of TFactS catalog (ver. 2)
TFs
a character vector of transcription factor
all.targets
a character vector of all target genes
TF.col
the name of the column that contains the TF names
lambda
a user-specified threshold of E-value (default: 0.05)
nRep
number of random selections (default: 100)
Author
Atsushi Fukushima
Definition:
m is the number of target genes annotated for the TF
under consideration
n is the number of query genes
N is the number of regulations in the catalog
k is the number of query genes that are annotated as
regulated by TF (i.e., the intersection between the
query and the TF signature)
References
Essaghir A et al. Nucleic Acids Res. 2010 Jun;38(11):e120.